request_span

Function request_span 

pub fn request_span(ctx: &Context) -> Span
Creates a tracing span for a Lambda request with context information.

This function creates a span that includes the request ID and optionally the X-Ray trace ID and tenant ID if they are available in the context.