[][src]Module lambda_runtime::error

The error module defines the error types that can be returned by custom handlers as well as the runtime itself.

Structs

HandlerError

The error type for functions that are used as the Handler type. New errors should be instantiated using the new_error() method of the runtime::Context object passed to the handler function.

RuntimeError

The RuntimeError object is returned by the custom runtime as it polls for new events and tries to execute the handler function. The error is primarily used by other methods within this crate and should not be relevant to developers building Lambda functions. Handlers are expected to return the HandlerError defined in this module.