[−][src]Module lambda_runtime::error
The error module defines the error types that can be returned by custom handlers as well as the runtime itself.
Structs
| HandlerError | The error type for functions that are used as the |
| RuntimeError | The |
The error module defines the error types that can be returned by custom handlers as well as the runtime itself.
| HandlerError | The error type for functions that are used as the |
| RuntimeError | The |