pub fn request_span(ctx: &Context) -> SpanExpand description
Creates a tracing span for a Lambda request with context information.
This function creates a span that includes the request ID and optionally the X-Ray trace ID and tenant ID if they are available in the context.